<?php 

// redirects - custom field allowing custom URL insertion
function pc_redirect_custom_field($field_id, $field, $value, $all_vals) {
	
	// WP pages list
	$pages = pc_get_pages(); 
	
	// label and note
	switch($field_id) {
		case 'pg_redirect_page' : 
			$label = __("Main redirect target for restricted pages", PC_ML); 
			$note = __('Unlogged users trying to reach restricted page will be moved there', PC_ML); 
			break;
			
		case 'pg_blocked_users_redirect' : 
			$label = __("Redirect target for blocked users", PC_ML); 
			$note = __('Logged users not matching specific restrictions will be moved there (eg. page visible only by unlogged)', PC_ML); 
			break;
		
		case 'pg_logged_user_redirect' : 
			$label = __("Redirect page after user's login", PC_ML); 
			$note = __("This value can be overwritten in user categories or through shortcode", PC_ML); 
			break;
			
		case 'pg_logout_user_redirect' : 
			$label = __("Redirect page after user's logout", PC_ML); 
			$note = __("This value can be overwritten through shortcode or using any URL + <strong>?pc_logout</strong>", PC_ML); 
			break;	
		
	}
	
	
	// main redirect - if no value - select first page
	if($field_id == 'pg_redirect_page' && !$value) {
		$value = key($pages);	
	}
	
	// options
	$opts = array(
		'' 			=> __('Do not redirect users', PC_ML), 
		'use_main' 	=> __('Use main redirect target', PC_ML),
		'custom' 	=> __('Custom redirect', PC_ML)
	) + $pages;
	
	// specific cases
	if($field_id == 'pg_redirect_page' || $field_id == 'pg_blocked_users_redirect') {unset($opts['']);}
	if($field_id != 'pg_blocked_users_redirect') {unset($opts['use_main']);}
	
	// custom text visibility
	$ct_vis = ($value == 'custom' || ($field_id == 'pg_redirect_page' && !$value)) ? '' : 'pc_displaynone';
	
	// custom text value
	$ct_val = isset($all_vals[$field_id .'_custom']) ? esc_attr($all_vals[$field_id .'_custom']) : '';
	
	
	// build code
	echo '
	<tr class="pc_'. $field_id .'">
		<td class="lcwp_sf_label" rowspan="2"><label>'. $label .'</label></td>
		<td class="lcwp_sf_field">
			<select name="'. $field_id .'" class="lcwp_sf_select pc_redirect_cf_select" autocomplete="off">';
			
				foreach($opts as $id => $name) {
					echo '<option value="'.$id.'" '.selected($value, $id).'>'.$name.'</option>';	
				}
	echo '
			</select>   
		</td>
		<td><p class="lcwp_sf_note">'. $note .'</p></td>
	</tr>
	<tr>
		<td colspan="2" class="pc_redirect_cfw '. $field_id .'_cfw '.$ct_vis.'">
			<input type="text" name="'. $field_id .'_custom" value="'.$ct_val.'" />
		</td>
	</tr>';
	
	?>
    <script type="text/javascript">
    (function($) { 
        "use strict";
        
        $(document).on('change', '.pc_redirect_cf_select', function(e) {
			var $subj = jQuery('.'+ jQuery(this).attr('name') +'_cfw');
			
			if(jQuery(this).val() == 'custom') {
				$subj.show();	
			} else {
				$subj.hide();
			}
		});
    })(jQuery);
    </script>
    <?php
}




// WP user sync - buttons
//// perform sync
function pc_do_wp_sync($field_id, $field, $value, $all_vals) {
	if($field['hide']) {return false;}
	?>
	<tr>
        <td colspan="2">
        	<input type="button" id="pc_do_wp_sync" class="button-secondary" value="<?php esc_attr_e('Sync users', PC_ML) ?>" />
        	<span class="pc_gwps_result"></span>
        </td>
        <td><span class="lcwp_sf_note"><strong><?php _e('Only users with unique username and e-mail will be synced', PC_ML) ?></strong></span></td>
    </tr>
    <?php	
}

//// sync existing users - only if $_GET['wps_existing_sync'] isset
function pc_wps_matches_sync($field_id, $field, $value, $all_vals) {
	if($field['hide'] || !isset($_GET['wps_existing_sync'])) {return false;}
	?>
	<tr>
        <td colspan="2">
        	<input type="button" id="pc_wps_matches_sync" class="button-secondary" value="<?php esc_attr_e('Search existing matches and sync', PC_ML) ?>" />
        	<span class="pc_gwps_result"></span>
        </td>
        <td><span class="lcwp_sf_note"><strong><?php _e('Search matches between existing PrivateContent and WP users, and sync them', PC_ML) ?></strong></span></td>
    </tr>
    <?php	
}

//// unsync
function pc_clean_wp_sync($field_id, $field, $value, $all_vals) {
	if($field['hide']) {return false;}
	?>
	<tr>
        <td colspan="2">
        	<input type="button" id="pc_clean_wp_sync" class="button-secondary" value="<?php esc_attr_e('Clear sync', PC_ML) ?>" />
        	<span class="pc_gwps_result"></span>
        </td>
        <td><span class="lcwp_sf_note"><strong><?php _e('Detach previous sync and delete related WP users', PC_ML) ?></strong></span></td>
    </tr>
    <?php	
}




// registration form builder
function pc_sc_reg_form_builder($field_id, $field, $value, $all_vals) {
?>
    <table id="pc_reg_form_builder_cmd_wrap" class="widefat">
        <tbody>
            <tr>
                <td>
                    <input type="text" name="pg_new_reg_form_name" id="pc_new_reg_form_name" placeholder="<?php esc_attr_e("New form's name", PC_ML) ?>" maxlength="150" autocomplete="off" />
                </td>
                <td>
                    <input type="button" value="<?php esc_attr_e('Add', PC_ML) ?>" id="pc_reg_form_add" class="button-secondary" />
                </td>
                <td>
                    <select name="pg_form_builder_dd" class="lcwp_sf_select pc_form_builder_dd" data-placeholder="<?php esc_attr_e('Select a form to edit', PC_ML) ?> .." autocomplete="off">
                        <?php 
                        $a = 0;
                        $reg_forms = get_terms('pc_reg_form', 'hide_empty=0&order=DESC');
                        foreach($reg_forms as $rf) {
                           $sel = (!$a) ? 'selected="selected"' : '';
                            
                           echo '<option value="'.$rf->term_id.'" '.$sel.'>'.$rf->term_id.' - '.$rf->name.'</option>';
                           $a++;
                        }
                        ?>
                    </select>
                </td>
                <td id="pc_reg_form_cmd">
                    <input type="button" value="<?php esc_attr_e('Save', PC_ML) ?>" class="pc_reg_form_save button-primary" />
                    <input type="button" value="<?php esc_attr_e('Delete', PC_ML) ?>" id="pc_reg_form_del" class="button-secondary" />
                </td>
            </tr> 	
        </tbody>
    </table>

    <i id="pc_reg_form_loader"></i>
    <br class="clear" /> 
    
    <div id="pc_reg_form_builder"></div>	
<?php	
}



// Fixed fields - placeholder and icons
function pc_fix_field_detail($field_id, $field, $value, $all_vals) {
	include_once(PC_DIR .'/classes/pc_form_framework.php');
	
	$f_fw = new pc_form;
	$fields = $f_fw->fields;
	$fname = $field['cb_subj'];
	
	switch($fname) {
		case 'name' 		: $label 	= __("Name's icon and placeholder text", PC_ML); break;
		case 'surname' 		: $label 	= __("Surname's icon and placeholder text", PC_ML); break;
		case 'username' 	: $label 	= __("Username's icon and placeholder text", PC_ML); break;
		case 'psw' 			: $label 	= __("Password's icon and placeholder text", PC_ML); break;
		case 'repeat_psw' 	: $label 	= __("Repeat password's icon and placeholder text", PC_ML); break;
		case 'categories' 	: $label 	= __("Category's icon and placeholder text", PC_ML); break;
		case 'email' 		: $label 	= __("E-mail's icon and placeholder text", PC_ML); break;
		case 'tel' 			: $label 	= __("Telephone's icon and placeholder text", PC_ML); break;	
	}
	
	
	$icon = get_option('pg_'. $fname .'_icon');
	$plac = get_option('pg_'. $fname .'_placeh', ($fname == 'repeat_psw') ? 'Repeat password' : $fields[$fname]['placeh']);
	?>
    <tr class="pc_<?php echo $field_id ?>">
		<td class="lcwp_sf_label">
        	<label><?php echo $label ?></label>
        </td>
		<td class="lcwp_sf_field">
			
            <div class="pc_field_icon_trigger">
            	<i class="fa <?php echo esc_attr($icon) ?>" title="<?php esc_attr_e("set field icon", PC_ML) ?>"></i>
                <input type="hidden" name="pg_<?php echo $fname ?>_icon" value="<?php echo esc_attr($icon) ?>" /> 
            </div>
            
           <input type="text" name="pg_<?php echo $fname ?>_placeh" value="<?php echo $plac ?>" class="pc_cust_field_placeh" />  
		</td>
	</tr>
    <?php
}



// Buttons icon
function pc_btns_icon($field_id, $field, $value, $all_vals) {
	$btn = $field['cb_subj'];
	$opt_name = 'pg_'. $btn .'_btn_icon';
	
	switch($btn) {
		case 'register' : $label 	= __("Registration form - button's icon", PC_ML); break;
		case 'login' 	: $label 	= __("Login form - button's icon", PC_ML); break;
		case 'logout' 	: $label 	= __("Logout button's icon", PC_ML); break;	
		case 'user_del' : $label 	= __("User deletion's icon", PC_ML); break;	
	}
	
	$icon = get_option($opt_name);
	?>
    <tr class="pc_<?php echo $field_id ?>">
		<td class="lcwp_sf_label">
        	<label><?php echo $label ?></label>
        </td>
		<td class="lcwp_sf_field">
			
            <div class="pc_field_icon_trigger">
            	<i class="fa <?php echo $icon ?>" title="set icon"></i>
                <input type="hidden" name="<?php echo $opt_name ?>" value="<?php echo $icon ?>" maxlength="40" /> 
            </div>
		</td>
	</tr>
    <?php
}



// Lightbox Instances
function pg_lightbox_instances($field_id, $field, $value, $all_vals) {
	?>
    <ul id="pc_lb_inst">
		<?php 
		$lb_instances = get_terms('pc_lightboxes', 'hide_empty=0&order=ASC');
		 
		if(empty($lb_instances)) : ?>
            <em><?php _e('no existing instances', PC_ML) ?> ..</em>
			
        <?php else : 
            $a = 0;
            foreach($lb_instances as $inst) : 
			
				if(isset($GLOBALS['pc_lb_data']) && isset($GLOBALS['pc_lb_data'][$inst->term_id])) {
					$note 		= $GLOBALS['pc_lb_data'][$inst->term_id]['note'];	
					$contents 	= $GLOBALS['pc_lb_data'][$inst->term_id]['contents'];	
				}
				else {
					$note 		= ($inst->name == '|||pclbft|||') ? '' : $inst->name;	
					$contents 	= base64_decode($inst->description);	
				}
				?>	
                
                <li>
                    <aside>
                        <span class="pc_del_field" rel="<?php echo $inst->term_id ?>" title="<?php esc_attr_e('remove restriction', PC_ML) ?>"></span>
                        <input type="hidden" name="pc_lb_id[]" value="<?php echo $inst->term_id ?>" />
                    </aside>    
                    <div class="pc_lb_inst_toprow">
                        <table>
                          <tr>
                            <td>
                                <input type="text" name="pc_lb_note[]" class="pc_lb_note" value="<?php echo $note ?>" placeholder="<?php esc_attr_e("Lightbox note (mandatory)", PC_ML) ?>" maxlength="250" autocomplete="off" />
                            </td>
                            <td>
                                <span><strong><?php _e('Trigger class', PC_ML) ?>:</strong> <em>pc_lb_trig_<?php echo $inst->term_id ?></em></span>
                                <strong>|</strong>
                                <span><strong><?php _e('Lightbox class', PC_ML) ?>:</strong> <em>pc_lb_<?php echo $inst->term_id ?></em></span>
                            </td>
                          </tr>
                        </table>
                    </div>                
                    <div class="pclb_editow_wrap">
                        <?php 
						$args = array('textarea_rows'=> 2);
						wp_editor($contents, 'pclb_'.$inst->term_id, $args); 
						?>
                    </div>
                </li>
            <?php endforeach;
         endif; ?>
    </ul>
    
    <?php // force textarea name to be array ?>
    <script type="text/javascript">
    (function($) { 
        "use strict";
        
        jQuery(document).ready(function(e) {
            setTimeout(function() {
                jQuery('.pclb_editow_wrap textarea.wp-editor-area').attr('name', 'pc_lb_contents[]');
            }, 500);
        });
    })(jQuery);    
    </script>
    <?php	
}



// URL-based restrictions
function pg_url_base_restr_field($field_id, $field, $value, $all_vals) {
	?>
    <ul id="pc_cr_list">
		<?php if(empty($all_vals['pg_cr_url'])) : ?>
            <em><?php _e('no custom restrictions added', PC_ML) ?> ..</em>
        <?php else : 
    
            $a = 0;
            foreach($all_vals['pg_cr_url'] as $pg_cr_url) {
                $block = (is_array($all_vals['pg_cr_block']) && isset($all_vals['pg_cr_block'][$a])) ? $all_vals['pg_cr_block'][$a] : array(); 
                
                echo pc_cr_template($pg_cr_url, $all_vals['pg_cr_allow'][$a], $block);
                $a++;	
            }
        
         endif; ?>
    </ul>
    <?php	
}



